@@ -22,7 +22,7 @@ def start_menu():
             {"name": "Manage existing repositories", "value": 1},
             {"name": "Create a new (remote) repository", "value": 2},
             {"name": "Manage my personal details", "value": 3},
-            {"name": "View and delete my SSH keys", "value": 4},
+            {"name": "Manage my SSH keys", "value": 4},
             {"name": "Show my language stats", "value": 5},
             Separator(),
             {"name": "Exit to shell", "value": 6},
